;; Generated package description from pulsar.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "pulsar" "1.3.4.0.20260424.102730" "Pulse highlight on demand or after select functions" '((emacs "28.1")) :commit "691ca967dee3269cb39a46a21fa2e848181a5ca5" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :keywords '("convenience" "pulse" "highlight") :url "https://github.com/protesilaos/pulsar")
